@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_
-#define VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_
+#ifndef ecflow_viewer_AbstractTextEditSearchInterface_HPP
+#define ecflow_viewer_AbstractTextEditSearchInterface_HPP
 
 #include <QColor>
 #include <QTextCursor>
@@ -21,7 +21,7 @@
 class AbstractTextEditSearchInterface {
 public:
     AbstractTextEditSearchInterface();
-    virtual ~AbstractTextEditSearchInterface()               = default;
+    virtual ~AbstractTextEditSearchInterface() = default;
 
     virtual bool findString(QString str,
                             bool highlightAll,
@@ -46,4 +46,4 @@ protected:
     VProperty* vpAutomaticSearchCase_;
 };
 
-#endif /* VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_ */
+#endif /* ecflow_viewer_AbstractTextEditSearchInterface_HPP */
