@@ -1,11 +1,21 @@
-#ifndef COMBOMULTI_HPP_
-#define COMBOMULTI_HPP_
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_viewer_ComboMulti_HPP
+#define ecflow_viewer_ComboMulti_HPP
 
 #include <QComboBox>
 #include <QItemDelegate>
 
 class ComboMulti : public QComboBox {
-    Q_OBJECT;
+    Q_OBJECT
 
 public:
     enum Mode { BasicMode, FilterMode };
@@ -63,4 +73,4 @@ Q_SIGNALS:
     void itemChecked() const;
 };
 
-#endif
+#endif /* ecflow_viewer_ComboMulti_HPP */
