@@ -1,23 +1,24 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef FILTERWIDGET_HPP_
-#define FILTERWIDGET_HPP_
+#ifndef ecflow_viewer_FileWidget_HPP
+#define ecflow_viewer_FileWidget_HPP
 
 #include <QMap>
 #include <QMenu>
 #include <QSet>
 #include <QWidget>
 
-#include "DState.hpp"
 #include "ServerFilter.hpp"
 #include "ServerList.hpp"
+#include "ecflow/core/DState.hpp"
 
 class QToolButton;
 class VParam;
@@ -93,4 +94,4 @@ protected:
     QFont loadFont_;
 };
 
-#endif
+#endif /* ecflow_viewer_FileWidget_HPP */
