@@ -41,8 +41,9 @@ QWidget* JobItemWidget::realWidget() {
 void JobItemWidget::reload(VInfo_ptr info) {
     assert(active_);
 
-    if (suspended_)
+    if (suspended_) {
         return;
+    }
 
     clearContents();
     info_ = info;
