@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef LOGLOADWIDGET_HPP
-#define LOGLOADWIDGET_HPP
+#ifndef ecflow_viewer_LogLoadWidget_HPP
+#define ecflow_viewer_LogLoadWidget_HPP
 
 #include <map>
 #include <string>
@@ -159,4 +159,4 @@ private:
     VProperty* expandFileInfoProp_{nullptr};
 };
 
-#endif // LOGLOADWIDGET_HPP
+#endif /* ecflow_viewer_LogLoadWidget_HPP */
