@@ -41,8 +41,9 @@ QWidget* ManualItemWidget::realWidget() {
 void ManualItemWidget::reload(VInfo_ptr info) {
     assert(active_);
 
-    if (suspended_)
+    if (suspended_) {
         return;
+    }
 
     clearContents();
 
