@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
-#ifndef VIEWER_SRC_OUTPUTBROWSER_HPP_
-#define VIEWER_SRC_OUTPUTBROWSER_HPP_
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_viewer_OutputBrowser_HPP
+#define ecflow_viewer_OutputBrowser_HPP
 
 #include <QLineEdit>
 #include <QMap>
@@ -136,4 +137,4 @@ private:
     static int minConfirmSearchSize_;
 };
 
-#endif /* VIEWER_SRC_OUTPUTBROWSER_HPP_ */
+#endif /* ecflow_viewer_OutputBrowser_HPP */
