@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef OUTPUTCHACHE_HPP_
-#define OUTPUTCHACHE_HPP_
+#ifndef ecflow_viewer_OutputCache_HPP
+#define ecflow_viewer_OutputCache_HPP
 
 #include <sstream>
 
@@ -48,7 +48,7 @@ class OutputCache : public QObject {
     Q_OBJECT
 
 public:
-    OutputCache(QObject* parent = nullptr);
+    explicit OutputCache(QObject* parent = nullptr);
     ~OutputCache() override;
 
     OutputCacheItem* add(VInfo_ptr info, const std::string& sourcePath, VFile_ptr file);
@@ -61,7 +61,7 @@ protected Q_SLOTS:
     void slotTimeOut();
 
 private:
-    OutputCache(const OutputClient&);
+    explicit OutputCache(const OutputClient&);
     OutputCache& operator=(const OutputCache&);
     void adjustTimer();
     void startTimer();
@@ -73,4 +73,4 @@ private:
     QTimer* timer_;
 };
 
-#endif // OUTPUTCHACHE_HPP
+#endif /* ecflow_viewer_OutputCache_HPP */
