@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef OVERVIEWITEMWIDGET_HPP_
-#define OVERVIEWITEMWIDGET_HPP_
+#ifndef ecflow_viewer_OverviewItemWidget_HPP
+#define ecflow_viewer_OverviewItemWidget_HPP
 
 #include "CodeItemWidget.hpp"
 #include "InfoPanelItem.hpp"
@@ -40,4 +40,4 @@ protected:
     int lastScrollPos_{0};
 };
 
-#endif
+#endif /* ecflow_viewer_OverviewItemWidget_HPP */
