@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef PROPERTYDIALOG_INC_
-#define PROPERTYDIALOG_INC_
+#ifndef ecflow_viewer_PropertyDialog_HPP
+#define ecflow_viewer_PropertyDialog_HPP
 
 #include <QDialog>
 
@@ -58,4 +59,4 @@ private:
     static VProperty* prop_;
 };
 
-#endif
+#endif /* ecflow_viewer_PropertyDialog_HPP */
