@@ -1,19 +1,20 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef SERVEROBSERVER_HPP_
-#define SERVEROBSERVER_HPP_
+#ifndef ecflow_viewer_ServerObserver_HPP
+#define ecflow_viewer_ServerObserver_HPP
 
 #include <string>
 #include <vector>
 
-#include "Aspect.hpp"
+#include "ecflow/node/Aspect.hpp"
 
 class ServerHandler;
 class VServerChange;
@@ -35,4 +36,4 @@ public:
     virtual void notifyServerRenamed(ServerHandler*, const std::string& /*oldName*/) {}
 };
 
-#endif
+#endif /* ecflow_viewer_ServerObserver_HPP */
