@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef TABLENODEMODEL_H
-#define TABLENODEMODEL_H
+#ifndef ecflow_viewer_TableNodeModel_HPP
+#define ecflow_viewer_TableNodeModel_HPP
 
 #include <QAbstractItemModel>
 
@@ -113,4 +114,4 @@ protected:
     int diagPixId_;
 };
 
-#endif
+#endif /* ecflow_viewer_TableNodeModel_HPP */
