@@ -124,25 +124,31 @@ void TimelineFileList::add(QString logFileIn) {
 
 int TimelineFileList::loadableCount() const {
     int t = 0;
-    Q_FOREACH (TimelineFileListItem item, items_)
-        if (item.loadable_)
+    Q_FOREACH (TimelineFileListItem item, items_) {
+        if (item.loadable_) {
             t++;
+        }
+    }
     return t;
 }
 
 qint64 TimelineFileList::totalSize() const {
     qint64 t = 0;
-    Q_FOREACH (TimelineFileListItem item, items_)
-        if (item.loadable_)
+    Q_FOREACH (TimelineFileListItem item, items_) {
+        if (item.loadable_) {
             t += item.size_;
+        }
+    }
 
     return t;
 }
 
 QString TimelineFileList::firstLoadablePath() const {
-    Q_FOREACH (TimelineFileListItem item, items_)
-        if (item.loadable_)
+    Q_FOREACH (TimelineFileListItem item, items_) {
+        if (item.loadable_) {
             return item.fileName_;
+        }
+    }
 
     return {};
 }
