@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef TRIGGERGRAPHVIEW_HPP
-#define TRIGGERGRAPHVIEW_HPP
+#ifndef ecflow_viewer_TriggerGraphView_HPP
+#define ecflow_viewer_TriggerGraphView_HPP
 
 #include <utility>
 
@@ -119,7 +120,7 @@ protected:
 class TriggerGraphEdgeInfoDialog : public QDialog {
     Q_OBJECT
 public:
-    TriggerGraphEdgeInfoDialog(QWidget* parent = nullptr);
+    explicit TriggerGraphEdgeInfoDialog(QWidget* parent = nullptr);
     void setInfo(TriggerGraphEdgeItem*);
     void readSettings(VComboSettings* vs);
     void writeSettings(VComboSettings* vs);
@@ -170,7 +171,7 @@ class TriggerGraphView : public QGraphicsView, public VPropertyObserver {
     friend class TriggeredRelationCollector;
 
 public:
-    TriggerGraphView(QWidget* parent = nullptr);
+    explicit TriggerGraphView(QWidget* parent = nullptr);
     ~TriggerGraphView() override;
 
     void clear(bool keepConfig = false);
@@ -283,4 +284,4 @@ protected:
     QBasicTimer delayedLayoutTimer_;
 };
 
-#endif // TRIGGERGRAPHVIEW_HPP
+#endif /* ecflow_viewer_TriggerGraphView_HPP */
