@@ -1,18 +1,18 @@
-//============================================================================
-// Copyright 2017 ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
 #include "VAutoCancelAttr.hpp"
 
-#include "NodeAttr.hpp"
 #include "VAttributeType.hpp"
 #include "VNode.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
 
 //================================
 // VAutoCancelAttrType
@@ -79,7 +79,7 @@ QStringList VAutoCancelAttr::data(bool /*firstLine*/) const {
 
 void VAutoCancelAttr::scan(VNode* vnode, std::vector<VAttribute*>& vec) {
     if (node_ptr node = vnode->node()) {
-        if (ecf::AutoCancelAttr* a = node->get_autocancel()) {
+        if (ecf::AutoCancelAttr* found = node->get_autocancel(); found) {
             vec.push_back(new VAutoCancelAttr(vnode));
         }
     }
