@@ -17,15 +17,17 @@ using Vec = std::vector<VSettingsLoader*>;
 static Vec* makers = nullptr;
 
 VSettingsLoader::VSettingsLoader() {
-    if (makers == nullptr)
+    if (makers == nullptr) {
         makers = new Vec();
+    }
 
     makers->push_back(Vec::value_type(this));
 }
 
 void VSettingsLoader::process() {
-    if (!makers)
+    if (!makers) {
         return;
+    }
 
     for (auto& maker : *makers) {
         maker->loadSettings();
