@@ -15,6 +15,8 @@
 
 #include "ecflow/base/AbstractClientEnv.hpp"
 #include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/AuthenticationDetails.hpp"
+#include "ecflow/base/AuthorisationDetails.hpp"
 #include "ecflow/base/cts/user/CtsApi.hpp"
 #include "ecflow/base/cts/user/DeleteCmd.hpp"
 #include "ecflow/base/stc/PreAllocatedReply.hpp"
@@ -30,8 +32,9 @@ using namespace boost;
 namespace po = boost::program_options;
 
 PathsCmd::PathsCmd(Api api, const std::string& absNodePath, bool force) : api_(api), force_(force) {
-    if (!absNodePath.empty())
+    if (!absNodePath.empty()) {
         paths_.push_back(absNodePath);
+    }
 }
 
 void PathsCmd::print(std::string& os) const {
@@ -40,8 +43,9 @@ void PathsCmd::print(std::string& os) const {
 
 std::string PathsCmd::print_short() const {
     std::vector<std::string> paths;
-    if (!paths_.empty())
+    if (!paths_.empty()) {
         paths.emplace_back(paths_[0]);
+    }
 
     std::string os;
     my_print_only(os, paths);
@@ -131,17 +135,29 @@ void PathsCmd::my_print_only(std::string& os, const std::vector<std::string>& pa
 
 bool PathsCmd::equals(ClientToServerCmd* rhs) const {
     auto* the_rhs = dynamic_cast<PathsCmd*>(rhs);
-    if (!the_rhs)
+    if (!the_rhs) {
         return false;
-    if (api_ != the_rhs->api())
+    }
+    if (api_ != the_rhs->api()) {
         return false;
-    if (paths_ != the_rhs->paths())
+    }
+    if (paths_ != the_rhs->paths()) {
         return false;
-    if (force_ != the_rhs->force())
+    }
+    if (force_ != the_rhs->force()) {
         return false;
+    }
     return UserCmd::equals(rhs);
 }
 
+ecf::authentication_t PathsCmd::authenticate(AbstractServer& server) const {
+    return implementation::do_authenticate(*this, server);
+}
+
+ecf::authorisation_t PathsCmd::authorise(AbstractServer& server) const {
+    return implementation::do_authorise(*this, server);
+}
+
 bool PathsCmd::isWrite() const {
     switch (api_) {
         case PathsCmd::SUSPEND:
@@ -160,8 +176,9 @@ bool PathsCmd::isWrite() const {
             return false;
             break; // read only
         case PathsCmd::EDIT_HISTORY: {
-            if (paths_.size() == 1 && paths_[0] == "clear")
+            if (paths_.size() == 1 && paths_[0] == "clear") {
                 return true; // requires write privilege
+            }
             return false;
             break; // read only
         }
@@ -284,8 +301,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
 
         case PathsCmd::EDIT_HISTORY: {
             as->update_stats().node_edit_history_++;
-            if (paths_.empty())
+            if (paths_.empty()) {
                 throw std::runtime_error("No paths/options specified for edit history");
+            }
             if (paths_.size() == 1 && paths_[0] == "clear") {
                 defs->clear_edit_history();
                 break;
@@ -298,8 +316,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
             use_EditHistoryMgr_ = false; // will add edit history ourselves
 
             as->update_stats().node_archive_++;
-            if (paths_.empty())
+            if (paths_.empty()) {
                 throw std::runtime_error("No paths specified for archive");
+            }
 
             // make sure paths don't overlap, Should not find same path up the hierarchy, which is also in paths_
             std::vector<NodeContainer*> containers_to_archive;
@@ -312,8 +331,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
                     continue;
                 }
                 NodeContainer* container = theNode->isNodeContainer();
-                if (!container)
+                if (!container) {
                     continue;
+                }
 
                 bool unique  = true;
                 Node* parent = theNode->parent();
@@ -325,18 +345,21 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
                     }
                     parent = parent->parent();
                 }
-                if (unique)
+                if (unique) {
                     containers_to_archive.push_back(container);
+                }
             }
 
             size_t vec_size = containers_to_archive.size();
             for (size_t i = 0; i < vec_size; i++) {
                 NodeContainer* the_container = containers_to_archive[i];
 
-                if (!force_)
+                if (!force_) {
                     DeleteCmd::check_for_active_or_submitted_tasks(as, the_container);
-                else
+                }
+                else {
                     as->zombie_ctrl().add_user_zombies(the_container, CtsApi::archive_arg());
+                }
 
                 SuiteChanged1 changed(the_container->suite());
 
@@ -351,8 +374,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
 
         case PathsCmd::RESTORE: {
             as->update_stats().node_restore_++;
-            if (paths_.empty())
+            if (paths_.empty()) {
                 throw std::runtime_error("No paths specified for restore");
+            }
             for (const auto& path : paths_) {
                 node_ptr theNode = find_node_for_edit_no_throw(defs, path);
                 if (!theNode.get()) {
@@ -361,8 +385,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
                     continue;
                 }
                 NodeContainer* container = theNode->isNodeContainer();
-                if (!container)
+                if (!container) {
                     continue;
+                }
 
                 SuiteChanged1 changed(container->suite());
                 container->restore(); // this can throw std::runtime_error
@@ -424,8 +449,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
                     acc_warning_msg += warning_msg;
                 }
                 std::string paths_not_fnd_error_msg = ss.str();
-                if (!paths_not_fnd_error_msg.empty())
+                if (!paths_not_fnd_error_msg.empty()) {
                     throw std::runtime_error(paths_not_fnd_error_msg);
+                }
                 return PreAllocatedReply::string_cmd(acc_warning_msg);
             }
             break;
@@ -453,9 +479,9 @@ STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
     return PreAllocatedReply::ok_cmd();
 }
 
-bool PathsCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
+// bool PathsCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+//     return do_authenticate(as, cmd, paths_);
+// }
 
 static const char* get_check_desc() {
     return "Checks the expression and limits in the server. Will also check trigger references.\n"
@@ -629,8 +655,9 @@ void PathsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, A
     assert(api_ != PathsCmd::NO_CMD);
 
     vector<string> args = vm[theArg()].as<vector<string>>();
-    if (ac->debug())
+    if (ac->debug()) {
         dumpVecArgs(theArg(), args);
+    }
 
     std::vector<std::string> options, paths;
     split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
@@ -641,8 +668,9 @@ void PathsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, A
         bool all        = false;
         size_t vec_size = options.size();
         for (size_t i = 0; i < vec_size; i++) {
-            if (args[i] == "_all_")
+            if (args[i] == "_all_") {
                 all = true;
+            }
         }
         if (!all && paths.empty()) {
             std::stringstream ss;
@@ -658,8 +686,9 @@ void PathsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, A
     else if (api_ == PathsCmd::EDIT_HISTORY) {
 
         if (paths.empty()) {
-            if (options.size() == 1 && options[0] == "clear")
+            if (options.size() == 1 && options[0] == "clear") {
                 paths.emplace_back("clear");
+            }
             else {
                 std::stringstream ss;
                 ss << theArg() << ":  No paths or option specified. Paths must begin with a leading '/' character\n";
