@@ -16,12 +16,16 @@
 
 namespace ecf {
 
-///
-/// \brief Message is a utility class that easily creates a string-based Message from an arbitrary set of inputs
-///
-/// The goal is to facilitate the construction/formatting of messages for error handling and logging.
-/// A Message implicitly allows conversion to std::string, and provides the streaming operator<<.
-///
+/**
+ * \brief Message is a utility class that easily creates a string-based Message from an arbitrary set of inputs
+ *
+ * The goal is to facilitate the construction/formatting of messages for error handling and logging.
+ * A Message implicitly allows conversion to std::string, and provides the streaming operator<<.
+ *
+ * In practice, this allows the user to do the following:
+ * ```std::string message = Message("this path:", path, ", is ok!");```
+ *
+ */
 class Message {
 public:
     template <typename... ARGS>
@@ -41,6 +45,24 @@ inline std::ostream& operator<<(std::ostream& o, const Message& m) {
     return o;
 }
 
+/**
+ * @brief  The stringize_f function is a helper to convert a functor to a string.
+ * @see macro MESSAGE()
+ *
+ * In practice, this allows the user to do the following:
+ *
+ * ```std::string message = MESSAGE("this path:" << path << ", is ok!");```
+ *
+ */
+template <typename Functor>
+std::string stringize_f(Functor const& f) {
+    std::ostringstream out;
+    f(out);
+    return out.str();
+}
+
+#define MESSAGE(EXPRESSION) (ecf::stringize_f([&](std::ostringstream& os) { os << EXPRESSION; }))
+
 } // namespace ecf
 
 #endif /* ecflow_core_Message_HPP */
