@@ -15,7 +15,6 @@
 
 #include "ecflow/test/scaffold/Naming.hpp"
 
-using namespace boost;
 using namespace std;
 
 // #define DEBUG_ME 1
@@ -48,8 +47,9 @@ public:
     }
 
     MyType& operator=(const MyType& other) {
-        if (this != &other)
+        if (this != &other) {
             mName = other.mName;
+        }
 #ifdef DEBUG_ME
         ECF_TEST_DBG("MyType::operator=(const MyType&) " << mName << " my_int:" << my_int_);
 #endif
@@ -57,8 +57,9 @@ public:
     }
 
     MyType& operator=(MyType&& other) noexcept {
-        if (this != &other)
+        if (this != &other) {
             mName = std::move(other.mName);
+        }
 #ifdef DEBUG_ME
         ECF_TEST_DBG("MyType::operator=(MyType&&) " << mName << " my_int:" << my_int_);
 #endif
