@@ -20,8 +20,9 @@ using namespace ecf;
 using namespace std;
 
 bool LateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (lineTokens.size() < 3)
+    if (lineTokens.size() < 3) {
         throw std::runtime_error("LateParser::doParse: Invalid late :" + line);
+    }
 
     // late -s +00:15  -a  20:00  -c +02:00     #The option can be in any order
     //  0   1    2      3   4     5     6        7     8     9  10 11 12  13
