@@ -21,10 +21,7 @@
 #include "ecflow/node/Task.hpp"
 #include "ecflow/test/scaffold/Naming.hpp"
 
-using namespace std;
 using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
 
 BOOST_AUTO_TEST_SUITE(U_Node)
 
@@ -43,8 +40,9 @@ BOOST_AUTO_TEST_CASE(test_repeat_day_time_combination_in_hierarchy) {
     //         time 10:00  # should run, monday at 10:00 twice, due to repeat
     //         time 11:00  # should run, monday at 11:00 twice, due to repeat
     Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
+    suite_ptr suite = defs.add_suite("s1");
+    auto the_time   = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 4),
+                                             boost::posix_time::time_duration(0, 0, 0)); // sunday
     suite->addClock(ClockAttr(the_time));
     family_ptr f  = suite->add_family("f");
     family_ptr f1 = f->add_family("f1");
@@ -55,15 +53,15 @@ BOOST_AUTO_TEST_CASE(test_repeat_day_time_combination_in_hierarchy) {
     t1->addTime(ecf::TimeAttr(ecf::TimeSlot(11, 0)));
     defs.beginAll();
 
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(10, 0, 0)); // Monday & 10
-    boost::posix_time::ptime expected_time2 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(11, 0, 0)); // Monday & 11
-    boost::posix_time::ptime expected_time3 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(10, 0, 0)); // Monday & 10
-    boost::posix_time::ptime expected_time4 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(11, 0, 0)); // Monday & 11
+    CalendarUpdateParams calUpdateParams(boost::posix_time::hours(1));
+    auto expected_time1 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 5),
+                                                   boost::posix_time::time_duration(10, 0, 0)); // Monday & 10
+    auto expected_time2 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 5),
+                                                   boost::posix_time::time_duration(11, 0, 0)); // Monday & 11
+    auto expected_time3 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 12),
+                                                   boost::posix_time::time_duration(10, 0, 0)); // Monday & 10
+    auto expected_time4 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 12),
+                                                   boost::posix_time::time_duration(11, 0, 0)); // Monday & 11
     // cout << defs << "\n";
 
     int submitted = 0;
@@ -84,28 +82,32 @@ BOOST_AUTO_TEST_CASE(test_repeat_day_time_combination_in_hierarchy) {
             // times[0].dump() << "\n";
 
             // 1st Run: Monday at 10:00 am
-            if (submitted == 1)
+            if (submitted == 1) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
                                     "\nExpected to submit at " << expected_time1 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             // 2nd Run: Monday at 11:00 am
-            if (submitted == 2)
+            if (submitted == 2) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time2,
                                     "\nExpected to submit at " << expected_time2 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             // 3rd Run: Monday at 10:00 am
-            if (submitted == 3)
+            if (submitted == 3) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
                                     "\nExpected to submit at " << expected_time3 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             // 4th Run: Monday at 11:00 am
-            if (submitted == 4)
+            if (submitted == 4) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time4,
                                     "\nExpected to submit at " << expected_time4 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             t1->set_state(NState::COMPLETE); // cause repeat to loop
             // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
@@ -129,8 +131,9 @@ BOOST_AUTO_TEST_CASE(test_repeat_time_day_combination_in_hierarchy) {
     //       task t1
     //          day monday
     Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
+    suite_ptr suite = defs.add_suite("s1");
+    auto the_time   = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 4),
+                                             boost::posix_time::time_duration(0, 0, 0)); // sunday
     suite->addClock(ClockAttr(the_time));
     family_ptr f  = suite->add_family("f");
     family_ptr f1 = f->add_family("f1");
@@ -140,11 +143,11 @@ BOOST_AUTO_TEST_CASE(test_repeat_time_day_combination_in_hierarchy) {
     t1->addDay(DayAttr(DayAttr::MONDAY));
     defs.beginAll();
 
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(0, 0, 0)); // Monday & 00:00
-    boost::posix_time::ptime expected_time3 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(0, 0, 0)); // Monday & 00:00
+    CalendarUpdateParams calUpdateParams(boost::posix_time::hours(1));
+    auto expected_time1 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 5),
+                                                   boost::posix_time::time_duration(0, 0, 0)); // Monday & 00:00
+    auto expected_time3 = boost::posix_time::ptime(boost::gregorian::date(2019, 8, 12),
+                                                   boost::posix_time::time_duration(0, 0, 0)); // Monday & 00:00
     // cout << defs << "\n";
 
     int submitted = 0;
@@ -165,16 +168,18 @@ BOOST_AUTO_TEST_CASE(test_repeat_time_day_combination_in_hierarchy) {
             // times[0].dump() << "\n";
 
             // 1st Run: Monday at 00:00 am
-            if (submitted == 1)
+            if (submitted == 1) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
                                     "\nExpected to submit at " << expected_time1 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             // 1st Run: Monday at 00:00 am
-            if (submitted == 2)
+            if (submitted == 2) {
                 BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
                                     "\nExpected to submit at " << expected_time3 << " only, but also found "
                                                                << suite->calendar().suiteTime());
+            }
 
             t1->set_state(NState::COMPLETE); // cause repeat to loop
             // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
@@ -202,7 +207,8 @@ BOOST_AUTO_TEST_CASE(test_repeat_with_impossible_day_combination_in_hierarchy) {
     //               verify complete:1
     Defs defs;
     suite_ptr suite = defs.add_suite("s1");
-    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
+    suite->addClock(ClockAttr(boost::posix_time::ptime(boost::gregorian::date(2019, 8, 4),
+                                                       boost::posix_time::time_duration(0, 0, 0)))); // sunday
     family_ptr f  = suite->add_family("f");
     family_ptr f1 = f->add_family("f1");
     f1->addRepeat(RepeatInteger("rep", 0, 1, 1)); // 2 iteration
@@ -212,7 +218,7 @@ BOOST_AUTO_TEST_CASE(test_repeat_with_impossible_day_combination_in_hierarchy) {
     t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
     defs.beginAll();
 
-    CalendarUpdateParams calUpdateParams(hours(1));
+    CalendarUpdateParams calUpdateParams(boost::posix_time::hours(1));
     // cout << defs << "\n";
 
     int submitted = 0;
