@@ -424,14 +424,17 @@ BOOST_AUTO_TEST_CASE(test_memento_persist_and_reload) {
         ecf::TimeSlot finish(10, 0);
         ecf::TimeSlot incr(0, 5);
         std::vector<int> weekdays;
-        for (int i = 0; i < 7; ++i)
+        for (int i = 0; i < 7; ++i) {
             weekdays.push_back(i);
+        }
         std::vector<int> daysOfMonth;
-        for (int i = 1; i < 32; ++i)
+        for (int i = 1; i < 32; ++i) {
             daysOfMonth.push_back(i);
+        }
         std::vector<int> months;
-        for (int i = 1; i < 13; ++i)
+        for (int i = 1; i < 13; ++i) {
             months.push_back(i);
+        }
         attr.addTimeSeries(start, finish, incr);
         attr.addWeekDays(weekdays);
         attr.addDaysOfMonth(daysOfMonth);
