@@ -11,11 +11,9 @@
 #ifndef ecflow_python_GlossaryDoc_HPP
 #define ecflow_python_GlossaryDoc_HPP
 
-#include <boost/core/noncopyable.hpp>
-
 // ===========================================================================
 // IMPORTANT: These appear as python doc strings.
-//            Additionally they are auto documented using sphinx-poco
+//            Additionally, they are auto-documented using sphinx-docs
 //            Hence the doc strings use reStructuredText markup.
 // ===========================================================================
 class GlossaryDoc {
