@@ -29,8 +29,9 @@
 #include "ecflow/core/CheckPt.hpp"
 #include "ecflow/core/CommandLine.hpp"
 #include "ecflow/core/Host.hpp"
-#include "ecflow/core/PasswdFile.hpp"
 #include "ecflow/core/WhiteListFile.hpp"
+#include "ecflow/server/AuthenticationService.hpp"
+#include "ecflow/server/AuthorisationService.hpp"
 #ifdef ECF_OPENSSL
     #include "ecflow/base/Openssl.hpp"
 #endif
@@ -122,8 +123,9 @@ public:
     /// set the check point interval. Typically set via client interface
     /// value should > 0 for valid values.
     void set_checkpt_interval(int v) {
-        if (v > 0)
+        if (v > 0) {
             checkPtInterval_ = v;
+        }
     }
 
     /// returns the check mode. This specifies options for saving of the checkPoint file:
@@ -162,9 +164,6 @@ public:
     /// If errors arise the exist user still stay in affect
     bool reloadWhiteListFile(std::string& errorMsg);
 
-    bool reloadPasswdFile(std::string& errorMsg);
-    bool reloadCustomPasswdFile(std::string& errorMsg);
-
     /// There are several kinds of authentification:
     ///     a/ None
     ///     b/ List mode.   ASCII file based on ECF_LISTS is defined
@@ -172,18 +171,27 @@ public:
     /// At the moment we will only implement options a/ and b/
     //
     /// Returns true if the given user has access to the server, false otherwise
-    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) const;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::string& path) const;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::vector<std::string>& paths) const;
-    bool authenticateWriteAccess(const std::string& user) const;
-    bool authenticateWriteAccess(const std::string& user, const std::string& path) const;
-    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const;
+    // bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) const;
+    // bool authenticateReadAccess(const std::string& user,
+    //                             bool custom_user,
+    //                             const std::string& passwd,
+    //                             const std::string& path) const;
+    // bool authenticateReadAccess(const std::string& user,
+    //                             bool custom_user,
+    //                             const std::string& passwd,
+    //                             const std::vector<std::string>& paths) const;
+    // bool authenticateWriteAccess(const std::string& user) const;
+    // bool authenticateWriteAccess(const std::string& user, const std::string& path) const;
+    // bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const;
+
+    ecf::AuthenticationService& authentication() { return authentication_service_; }
+    const ecf::AuthenticationService& authentication() const { return authentication_service_; }
+
+    ecf::AuthorisationService& authorisation() { return authorisation_service_; }
+    const ecf::AuthorisationService& authorisation() const { return authorisation_service_; }
+
+    // const PasswdFile& passwd_file() const { return passwd_file_; }
+    // const PasswdFile& passwd_custom_file() const { return passwd_custom_file_; }
 
     /// return true if help option was selected
     bool help_option() const { return help_option_; }
@@ -239,10 +247,8 @@ private:
     std::string ecf_white_list_file_;
     mutable WhiteListFile white_list_file_;
 
-    std::string ecf_passwd_file_;
-    std::string ecf_passwd_custom_file_;
-    mutable PasswdFile passwd_file_;
-    mutable PasswdFile passwd_custom_file_;
+    mutable ecf::AuthenticationService authentication_service_;
+    mutable ecf::AuthorisationService authorisation_service_;
 
 #ifdef ECF_OPENSSL
     ecf::Openssl ssl_;
